==> visitor_analytics-8.x-1.1.tar.gz: visitor_analytics/src/Controller/MainPageController.php <==
<?php

namespace Drupal\visitor_analytics\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\visitor_analytics\VisitorAnalyticsAddSiteFailureException;
use Drupal\visitor_analytics\VisitorAnalyticsAlreadyUsedFreeTrialException;
use Drupal\visitor_analytics\VisitorAnalyticsAuthExpiredException;
use Drupal\visitor_analytics\VisitorAnalyticsRequest;
use Drupal\visitor_analytics\VisitorAnalyticsSiteNotFoundException;

/**
 * Class MainPageController.
 */
class MainPageController extends ControllerBase {

  /**
   * Page.
   *
   * @return string
   *   Return Hello string.
   */
  public function page() {
    // check if there's state data
    $visitor_analytics_data = \Drupal::state()->get('visitor_analytics', []);

    if (isset($visitor_analytics_data['token'])) {
      try {
        $request = new VisitorAnalyticsRequest($visitor_analytics_data['token']);

        // refresh token if needed
        if ((time() - $visitor_analytics_data['token_created']) > VisitorAnalyticsRequest::TOKEN_LIFETIME) {
          $response_data = \GuzzleHttp\json_decode($request->refreshToken($visitor_analytics_data['refreshToken'])
            ->getBody());
          $visitor_analytics_data['token'] = $response_data->token;
          $visitor_analytics_data['refreshToken'] = $response_data->refreshToken;
          $visitor_analytics_data['userId'] = $response_data->userId;
          \Drupal::state()->set('visitor_analytics', $visitor_analytics_data);
          $request->setToken($visitor_analytics_data['token']);
        }

        // get (or add) website
        try {
          $website_data = \GuzzleHttp\json_decode($request->getWebsite(\Drupal::request()
            ->getSchemeAndHttpHost())->getBody());
        } catch (VisitorAnalyticsSiteNotFoundException $e) {
          // try to add the site
          $website_data = \GuzzleHttp\json_decode($request->addWebsite(
            \Drupal::request()->getSchemeAndHttpHost(),
            drupal_get_user_timezone())->getBody());
        }
        $visitor_analytics_data['website_id'] = $website_data->id;
        \Drupal::state()->set('visitor_analytics', $visitor_analytics_data);

        // start free trial if needed
        if (!isset($visitor_analytics_data['trialEndsAt'])) {
          try {
            $trial_data = \GuzzleHttp\json_decode($request->freeTrialStart($visitor_analytics_data['website_id'])
              ->getBody());
            $visitor_analytics_data['trialEndsAt'] = $trial_data->trialEndsAt;
          } catch (VisitorAnalyticsAlreadyUsedFreeTrialException $e) {
            // we need to set it though we don't know when it would end at this point
            // this can occur when you work with same site&account from different environments (localhosts)
            $visitor_analytics_data['trialEndsAt'] = 0;
          }
          \Drupal::state()->set('visitor_analytics', $visitor_analytics_data);
        }

        if (isset($visitor_analytics_data['website_id']) && !isset($visitor_analytics_data['trackingCode'])) {
          // try to get tracking code
          $tracker_data = \GuzzleHttp\json_decode($request->getTrackerCode($visitor_analytics_data['website_id'])
            ->getBody());
          $visitor_analytics_data['trackingCode'] = $tracker_data->trackingCode;
          \Drupal::state()->set('visitor_analytics', $visitor_analytics_data);
          \Drupal::messenger()
            ->addMessage($this->t('Tracking code is loaded successfully.'));
        }
      } catch (VisitorAnalyticsAuthExpiredException $e) {
        \Drupal::messenger()->addError($this->t($e->getMessage()));
        return $this->redirect('visitor_analytics.login_form');
      } catch (VisitorAnalyticsSiteNotFoundException $e) {
        \Drupal::messenger()->addError($this->t($e->getMessage()));
        return $this->redirect('visitor_analytics.login_form');
      } catch (VisitorAnalyticsAddSiteFailureException $e) {
        \Drupal::messenger()->addError($this->t($e->getMessage()));
        return $this->redirect('visitor_analytics.login_form');
      } catch (\Exception $e) {
        \Drupal::messenger()->addError($this->t($e->getMessage()));
        \Drupal::logger('visitor_analytics')->error($this->t($e->getMessage()));
      }

      // if there is enough data, render the iframe
      if (isset($visitor_analytics_data['token']) && isset($visitor_analytics_data['website_id']) && isset($visitor_analytics_data['userId'])) {
        return [
          '#theme' => 'visitor_analytics_iframe',
          '#token' => $visitor_analytics_data['token'],
          '#website_id' => $visitor_analytics_data['website_id'],
          '#userId' => $visitor_analytics_data['userId'],
        ];
      }

      return [
        '#type' => 'markup',
        '#markup' => $this->t('Something went wrong.'),
      ];
    }

    if (isset($visitor_analytics_data['email'])) {
      return $this->redirect('visitor_analytics.login_form');
    }

    return $this->redirect('visitor_analytics.register_form');
  }

}

==> visitor_analytics-8.x-1.3.tar.gz: visitor_analytics/src/Controller/MainPageController.php <==
<?php

namespace Drupal\visitor_analytics\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\visitor_analytics\VisitorAnalyticsAddSiteFailureException;
use Drupal\visitor_analytics\VisitorAnalyticsAlreadyUsedFreeTrialException;
use Drupal\visitor_analytics\VisitorAnalyticsAuthExpiredException;
use Drupal\visitor_analytics\VisitorAnalyticsRequest;
use Drupal\visitor_analytics\VisitorAnalyticsSiteNotFoundException;
use Drupal\visitor_analytics\VisitorAnalyticsUserNotFoundException;

/**
 * Class MainPageController.
 */
class MainPageController extends ControllerBase {

  /**
   * Page.
   *
   * @return string
   *   Return Hello string.
   */
  public function page() {
    // check if there's state data
    $visitor_analytics_data = \Drupal::state()->get('visitor_analytics', []);

    if (isset($visitor_analytics_data['token'])) {
      try {
        $request = new VisitorAnalyticsRequest($visitor_analytics_data['token']);

        // refresh token if needed
        if ((time() - $visitor_analytics_data['token_created']) > VisitorAnalyticsRequest::TOKEN_LIFETIME) {
          $response_data = \GuzzleHttp\json_decode($request->refreshToken($visitor_analytics_data['refreshToken'])
            ->getBody());
          $visitor_analytics_data['token'] = $response_data->token;
          $visitor_analytics_data['refreshToken'] = $response_data->refreshToken;
          $visitor_analytics_data['userId'] = $response_data->userId;
          \Drupal::state()->set('visitor_analytics', $visitor_analytics_data);
          $request->setToken($visitor_analytics_data['token']);
        }

        // get (or add) website
        try {
          $website_data = \GuzzleHttp\json_decode($request->getWebsite(\Drupal::request()
            ->getSchemeAndHttpHost())->getBody());
        } catch (VisitorAnalyticsSiteNotFoundException $e) {
          // try to add the site
          $website_data = \GuzzleHttp\json_decode($request->addWebsite(
            \Drupal::request()->getSchemeAndHttpHost(),
            drupal_get_user_timezone())->getBody()
          );
          // start free trial
          try {
            $request->freeTrialStart($website_data->id);
          } catch (VisitorAnalyticsAlreadyUsedFreeTrialException $e) {
            // nothing to do, it's just already started
          }
        }
        $visitor_analytics_data['website_id'] = $website_data->id;
        \Drupal::state()->set('visitor_analytics', $visitor_analytics_data);

        if (isset($visitor_analytics_data['website_id']) && !isset($visitor_analytics_data['trackingCode'])) {
          // try to get tracking code
          $tracker_data = \GuzzleHttp\json_decode($request->getTrackerCode($visitor_analytics_data['website_id'])
            ->getBody());
          $visitor_analytics_data['trackingCode'] = $tracker_data->trackingCode;
          \Drupal::state()->set('visitor_analytics', $visitor_analytics_data);
          \Drupal::messenger()
            ->addMessage($this->t('Tracking code is loaded successfully.'));
        }
      } catch (VisitorAnalyticsAuthExpiredException $e) {
        \Drupal::messenger()->addError($this->t($e->getMessage()));
        return $this->redirect('visitor_analytics.login_form');
      } catch (VisitorAnalyticsSiteNotFoundException $e) {
        \Drupal::messenger()->addError($this->t($e->getMessage()));
        return $this->redirect('visitor_analytics.login_form');
      } catch (VisitorAnalyticsAddSiteFailureException $e) {
        \Drupal::messenger()->addError($this->t($e->getMessage()));
        return $this->redirect('visitor_analytics.login_form');
      } catch (VisitorAnalyticsUserNotFoundException $e) {
        \Drupal::messenger()->addError($this->t($e->getMessage()));
        return $this->redirect('visitor_analytics.register_form');
      } catch (\Exception $e) {
        \Drupal::messenger()->addError($this->t($e->getMessage()));
        \Drupal::logger('visitor_analytics')->error($this->t($e->getMessage()));
      }

      // if there is enough data, render the iframe
      if (isset($visitor_analytics_data['token']) && isset($visitor_analytics_data['website_id']) && isset($visitor_analytics_data['userId'])) {
        return [
          '#theme' => 'visitor_analytics_iframe',
          '#token' => $visitor_analytics_data['token'],
          '#website_id' => $visitor_analytics_data['website_id'],
          '#userId' => $visitor_analytics_data['userId'],
        ];
      }

      return [
        '#type' => 'markup',
        '#markup' => $this->t('Something went wrong.'),
      ];
    }

    if (isset($visitor_analytics_data['email'])) {
      return $this->redirect('visitor_analytics.login_form');
    }

    return $this->redirect('visitor_analytics.register_form');
  }

}
